@@ -10,10 +10,11 @@ use Cwd qw(abs_path);
 use Scalar::Util 'blessed';
 
 use Number::Phone::Country qw(noexport);
+use Number::Phone::Data;
 use Number::Phone::StubCountry;
 
 # MUST be in format N.NNNN, see https://github.com/DrHyde/perl-modules-Number-Phone/issues/58
-our $VERSION = '3.6006';
+our $VERSION = '3.8002';
 
 my $NOSTUBS = 0;
 sub import {
@@ -24,6 +25,10 @@ sub import {
   }
 }
 
+if(~0 == 4294967295) {
+    warn("Your perl only supports 32 bit ints; Number::Phone will require 64 bit ints from some time after 2023-06-01");
+}
+
 sub _find_data_file {
     my $wanted = shift;
 
@@ -43,7 +48,7 @@ sub _find_data_file {
 
     if(!$file) {
         die(
-            "Couldn't find a UK data file amongst:\n".
+            "Couldn't find data file '$wanted' amongst:\n".
             join('', map { "  $_\n" } @candidate_files)
         );
     }
@@ -62,7 +67,7 @@ foreach my $method (
     @is_methods, qw(
         country_code regulator areacode areaname
         subscriber operator operator_ported translates_to
-        format location
+        format location data_source
     )
 ) {
     no strict 'refs';
@@ -87,17 +92,20 @@ sub dial_to {
 
   if($from->country_code() != $to->country_code()) {
     return Number::Phone::Country::idd_code($from->country()).
-           $to->country_code().
-           ($to->areacode() ? $to->areacode() : '').
-           $to->subscriber();
+        $to->country_code().
+        ($to->isa('Number::Phone::StubCountry')
+          ? $to->raw_number()
+          : (
+              ($to->areacode() ? $to->areacode() : '').
+              $to->subscriber()
+            )
+        );
   }
 
-  # if we get here it's a domestic call
-
   # do we know how to do this?
   my $intra_country_dial_to = eval '$from->intra_country_dial_to($to)';
   return undef if($@); # no
-  return $intra_country_dial_to if($intra_country_dial_to); # yes, and here's how
+  return $intra_country_dial_to if(defined($intra_country_dial_to)); # yes, and here's how
 
   # if we get here, then we can use the default implementation ...
 
@@ -175,7 +183,7 @@ bad design decision. Use of those calling conventions was deprecated
 in version 2.0, released in January 2012, and started to emit
 warnings. All code to support those calling conventions has now been removed.
 
-Until 2017 we ued KOS for the country code for Kosovo, that has now changed to
+Until 2017 we used KOS for the country code for Kosovo, that has now changed to
 XK. See L<Number::Phone::Country>.
 
 From version 3.4000 to 3.4003 inclusive we accepted any old garbage after
@@ -197,7 +205,14 @@ As of version 3.6000 the C<areaname> method pays attention to your locale
 settings and so you might start getting locale-appropriate versions of
 areanames instead of what you used to get.
 
-=head1 COMPATIBILTY WITH libphonenumber
+64 bit ints will be required some time after 2023-06-01.
+
+3.8000 is a bit stricter about numbers and countries not matching in the
+constructor. This may affect users who specify places like Guernsey but
+provide numbers from Jersey or the Isle of Man, all three of which are separate
+jurisdictions squatting on random places all over the UK's number plan.
+
+=head1 COMPATIBILITY WITH libphonenumber
 
 libphonenumber is a similar project for other languages, maintained
 by Google.
@@ -223,25 +238,38 @@ want to do this for compatibility or performance. Number::Phone::UK is quite slo
 sub _new_args {
     my $class = shift;
     my($country, $number) = @_;
+    die("Number::Phone->new(): too many params\n") if(exists($_[2]));
+
+    my $original_country;
 
     if(!defined($number)) { # one arg
-      $number = $country;
+        $number = $country;
     } elsif($country =~ /[a-z]/i) { # eg 'UK', '12345'
-      $number = '+'.
-                Number::Phone::Country::country_code($country).
-		$number
-        unless(index($number, '+'.Number::Phone::Country::country_code($country)) == 0);
+        $original_country = uc($country);
+        $number = '+'.
+                  Number::Phone::Country::country_code($country).
+                  $number
+          unless(index($number, '+'.Number::Phone::Country::country_code($country)) == 0);
     } else { # (+)NNN
-      $number = join('', grep { defined } ($country, $number));
+        $number = join('', grep { defined } ($country, $number));
     }
 
-    die("Number::Phone->new(): too many params\n")
-        if(exists($_[2]));
     $number =~ s/[^+0-9]//g;
-
     $number = "+$number" unless($number =~ /^\+/);
+
     $country = Number::Phone::Country::phone2country($number) or return;
-    return $country, $number;
+
+    # special cases where you can legitimately ask for a containing country (eg
+    # GB) and get back a sub-country (eg GG, which squats upon parts of the GB
+    # number plan)
+    if(
+        ($country eq 'VA'           && $original_country eq 'IT') ||
+        ($country =~ /^(IM|GG|JE)$/ && $original_country eq 'GB')
+    ) {
+        $original_country = $country;
+    }
+
+    return ($original_country || $country), $number;
 }
 
 sub new {
@@ -250,35 +278,46 @@ sub new {
     return undef unless($country);
     if ($number =~ /^\+1/) {
         $country = "NANP";
-    } elsif ($country =~ /^(?:GB|GG|JE|IM)$/) {
+    } elsif($country eq 'GB') {
+        # for hysterical raisins
         $country = 'UK';
+    } elsif($country =~ /^(GG|JE|IM)$/) {
+        $country = "UK::$country";
     }
     eval "use Number::Phone::$country";
     if($@ || !"Number::Phone::$country"->isa('Number::Phone')) {
+        if($@ =~ /--without_uk/) {
+            # a test unexpectedly tried to load Number::Phone::UK, argh!
+            die $@
+        }
+        # undo the above transformations, for stub-land
+        if($country eq 'UK') { $country = 'GB' }
+        if($country =~ /^UK::(..)/) { $country = $1 }
         return $class->_make_stub_object($number, $country)
     }
     return "Number::Phone::$country"->new($number);
 }
 
 sub _make_stub_object {
- my ($class, $number, $country_name) = @_;
-  die("no module available for $country_name, and nostubs turned on\n") if($NOSTUBS);
-  my $stub_class = "Number::Phone::StubCountry::$country_name";
-  eval "use $stub_class";
-  # die("Can't find $stub_class: $@\n") if($@);
-  if($@) {
-      my (undef, $country_idd) = Number::Phone::Country::phone2country_and_idd($number);
-      # an instance of this class is the ultimate fallback
-      (my $local_number = $number) =~ s/(^\+$country_idd|\D)//;
-      if($local_number eq '') { return undef; }
-      return bless({
-          country_code => $country_idd,
-          country      => $country_name,
-          is_valid     => undef,
-          number       => $local_number,
-      }, 'Number::Phone::StubCountry');
-  }
-  $stub_class->new($number);
+    my ($class, $number, $country_name) = @_;
+    die("no module available for $country_name, and nostubs turned on\n") if($NOSTUBS);
+    my $stub_class = "Number::Phone::StubCountry::$country_name";
+    eval "use $stub_class";
+    # die("Can't find $stub_class: $@\n") if($@);
+    if($@) {
+        my (undef, $country_idd) = Number::Phone::Country::phone2country_and_idd($number);
+        # an instance of this class is the ultimate fallback
+        (my $local_number = $number) =~ s/(^\+$country_idd|\D)//;
+        if($local_number eq '') { return undef; }
+        return bless({
+            country_code => $country_idd,
+            country      => $country_name,
+            is_valid     => undef,
+            number       => $local_number,
+        }, 'Number::Phone::StubCountry');
+    }
+
+    $stub_class->new($number);
 }
 
 =head1 METHODS
@@ -544,6 +583,28 @@ The superclass implementation returns undef.
 
 =back
 
+=head2 DATA SOURCES
+
+=over
+
+=item data_source
+
+Class method, return some hopefully useful text about the source of the data
+(if any) that drives a country-specific module. The implementation in the base
+class returns undef as the base class itself has no data source.
+
+=item libphonenumber_tag
+
+Class method which you should not over-ride, implemented in the base class.
+Returns the version of libphonenumber whose metadata was used for this release
+of Number::Phone. NB that this is derived from their most recent git tag, so
+may occasionally be a little ahead of the most recent libphonenumber release as
+the tag gets created before their release is built.
+
+The current version of this is also documented in L<Number::Phone::Data>.
+
+=back
+
 =head2 HOW TO DIAL FROM ONE NUMBER TO ANOTHER
 
 =over
@@ -585,8 +646,8 @@ follows:
 =item international call
 
 Append together the source country's international dialling prefix
-(usually 00), then the destination country's code code, area code,
-and subscriber number.
+(usually 00), then the destination country's country code, area code
+(if the country has such a thing), and subscriber number.
 
 =item domestic call, different area code
 
@@ -643,16 +704,38 @@ the phone number is passed to its constructor unchanged.
 If only one parameter is passed, then we try to figure out which is the right
 country subclass to use by pre-pending a + sign to the number if
 there isn't one, and looking the country up using
-Number::Phone::Country.  That gives us a two letter country code that
-is used to try to load the right module.
+Number::Phone::Country. That gives us a two letter country code that
+is used to try to load the right module. We then pass the number through to
+that module's constructor and return whatever it says (which may be undef
+if you pass in an invalid number - see SUBCLASSING below).
 
 The constructor returns undef if it can not figure out what country
 you're talking about, or an object based on Google's libphonenumber
 data if there's no complete country-specific module available.
 
 It is generally assumed that numbers are complete and unambiguous - ie you
-can't pass just the local part to the constructor if the number has an area
-code. Any subclass's constructor which contravenes this should document it.
+can't normally pass just the local part to the constructor if the number has an
+area code. Any subclass's constructor which contravenes this should document
+it.
+
+If you call it with two parameters, then the two must match. ie, if you
+do this:
+
+    Number::Phone->new("FR", "+441424220001")
+
+you will get C<undef> back because whiel the number is valid, it ain't French.
+This usually applies to the case where a single country's number plan contains
+other jurisdictions, such as the case of Guernsey, Jersey and the Isle of Man
+squatting on the United Kingdom's number plan. For example, this fails, because
+the number is from Guernsey, not Jersey:
+
+    Number::Phone->new('JE', '01481256789')
+
+For backward compatibility and convenience, however, if you ask for an object
+representing a number in the "host" country but pass a number for the
+"sub-country" then you'll get back a valid object representing the sub-country:
+
+    my $gg_number = Number::Phone->new('GB', '01481256789')
 
 =back
 
