@@ -7,7 +7,7 @@ use Number::Phone::UK::Data;
 
 use base 'Number::Phone';
 
-our $VERSION = '1.68';
+our $VERSION = '1.71';
 
 my $cache = {};
 
@@ -30,7 +30,9 @@ sub new {
     $number = '+44'._clean_number($number);
     if(is_valid($number)) {
         $number =~ s/^0/+44/;
-        return bless(\$number, $class->_get_class(_clean_number($number)));
+        my $target_class = $class->_get_class(_clean_number($number));
+        return undef if($class ne $target_class);
+        return bless(\$number, $target_class);
     } else { return undef; }
 }
 
@@ -65,6 +67,14 @@ The following methods from Number::Phone are overridden:
 The constructor, you should never have to call this yourself. To create an
 object the canonical incantation is C<< Number::Phone->new('+44 ...') >>.
 
+=item data_source
+
+Returns a string telling where and when the data that drives this class was last updated, looking something like:
+
+    "OFCOM at Wed Sep 30 10:37:39 2020 UTC"
+
+The current value of this is also documented in L<Number::Phone::Data>.
+
 =item is_valid
 
 The number is valid within the national numbering scheme.  It may or may
@@ -78,7 +88,10 @@ sub _get_class {
   my $number = shift;
   foreach my $prefix (_prefixes($number)) {
     if(exists(Number::Phone::UK::Data::db()->{subclass}->{$prefix})) {
-      my $subclass = join('::', $class, Number::Phone::UK::Data::db()->{subclass}->{$prefix});
+      return $class if(Number::Phone::UK::Data::db()->{subclass}->{$prefix} eq '');
+
+      my $desired_subclass = Number::Phone::UK::Data::db()->{subclass}->{$prefix};
+      my $subclass = "Number::Phone::UK::$desired_subclass";
       eval "use $subclass";
       return $subclass;
     }
@@ -122,6 +135,9 @@ sub is_valid {
     # quickly check length
     return $cache->{$number}->{is_valid} = 0 if(length($cleaned_number) < 7 || length($cleaned_number) > 10);
 
+    # 04 and 06 are invalid, only 05[56] are valid
+    return $cache->{$number}->{is_valid} = 0 if($cleaned_number =~ /^(4|5[01234789]|6)/);
+
     # slightly more rigourous length check for some unallocated geographic numbers
     # 07, 02x and 011x are always ten digits
     return $cache->{$number}->{is_valid} = 0 if($cleaned_number =~ /^([27]|11)/ && length($cleaned_number) != 10);
@@ -206,9 +222,7 @@ sub is_drama {
     );
 
     foreach my $d (@drama_numbers) {
-        
         return 1 if ($num =~ $d);
-    
     }
 
     return 0;
@@ -416,8 +430,8 @@ sub format {
 
 Within the UK numbering plan you can *always* dial 0xxxx xxxxxx
 for intra-country calls. In most places the leading 0$areacode is
-optional but in some it is required (see
-L<http://consumers.ofcom.org.uk/dial-the-code/>) and over time this
+optional but in some it is required (see eg
+L<https://www.ofcom.org.uk/__data/assets/pdf_file/0017/19160/aberdeen_local_dialling_release.pdf>) and over time this
 will apply to more areas.
 
 =cut
@@ -426,6 +440,7 @@ sub intra_country_dial_to {
   my $from = shift;
   my $to   = shift;
 
+  die if(!$to->is_allocated());
   return '0'.($to->areacode() ? $to->areacode() : '').$to->subscriber();
 }
 
