@@ -135,23 +135,23 @@ skip_if_libphonenumber("Stubs don't support operator", 1, sub {
         ['+1 242 225 0000' => 'BAHAMAS TELECOMMUNICATIONS CORP.'],
         ['+1 246 220 0000' => 'CABLE & WIRELESS BARBADOS'],
         ['+1 264 222 0000' => 'CABLE & WIRELESS - ANGUILLA'],
-        ['+1 268 222 0000' => 'CABLE & WIRELESS - ANTIGUA'],
+        ['+1 268 268 0000' => 'CABLE & WIRELESS - ANTIGUA'],
         ['+1 284 229 0000' => 'CABLE & WIRELESS - TORTOLA'],
         ['+1 340 774 5666' => 'VIRGIN ISLANDS TEL. CORP. DBA INNOVATIVE TELEPHONE'],
         ['+1 345 222 0000' => 'CABLE & WIRELESS - CAYMAN ISLANDS'],
-        ['+1 441 222 0000' => 'Bermuda Cablevision Ltd'],
+        ['+1 441 222 0000' => 'BERMUDA CABLEVISION LIMITED - BM'],
         ['+1 473 230 0000' => 'COLUMBUS COMMUNICATIONS (GRENADA) LIMITED'],
         ['+1 649 231 0000' => 'CABLE & WIRELESS - TURKS & CAICOS'],
         # No data yet.
-        # checked on 2020-06-06
-        # next check due 2020-12-01 (semi-annually) until there's data
+        # checked on 2020-12-04
+        # next check due 2021-12-01 (annually) until there's data
         # at https://localcallingguide.com/xmlprefix.php?npa=658&blocks=1
         # ['+1 658 ??? 0000' => '???'],
         ['+1 664 349 0000' => 'CABLE & WIRELESS - MONTSERRAT'],
-        ['+1 670 233 0000' => 'MICRONESIAN TELECOMMUNICATIONS CORP.'],
+        ['+1 670 233 0000' => 'MICRONESIAN TELECOMMUNICATIONS CORPORATION'],
         ['+1 671 472 7679' => 'TELEGUAM HOLDINGS, LLC'],
         ['+1 684 248 0000' => 'AST TELECOM, LLC - AS'],
-        ['+1 721 510 0000' => 'UTS RADCOMM'],
+        ['+1 721 547 0000' => 'ST. MAARTEN TELEPHONE COMPANY, NV'],
         ['+1 758 234 0000' => 'CABLE & WIRELESS - ST. LUCIA, LTD'],
         ['+1 767 221 0000' => 'DIGICEL (GRENADA) LIMITED'],
         ['+1 784 266 0000' => 'CABLE & WIRELESS - ST. VINCENT'],
@@ -159,7 +159,7 @@ skip_if_libphonenumber("Stubs don't support operator", 1, sub {
         ['+1 809 202 0000' => 'ECONOMITEL, C. POR A. - DR'],
         ['+1 829 201 0000' => 'CODETEL'],
         ['+1 849 201 0000' => 'CODETEL'],
-        ['+1 868 201 0000' => 'Open Telecom Ltd'],
+        ['+1 868 215 0000' => 'COLUMBUS COMMUNICATIONS TRINIDAD LIMITED'],
         ['+1 869 212 0000' => 'ST KITTS NEVIS TELEPHONE - NEVIS'],
         ['+1 876 202 0000' => 'JAMAICA TELEPHONE CO.'],
         ['+1 939 201 0000' => 'AT&T, INC. - PR'],
@@ -174,13 +174,13 @@ skip_if_libphonenumber("Stubs don't support operator", 1, sub {
         "Oh good, the database contains data for all the non-US/CA area codes (except 658, for which no data are yet available)"
     );
 
-    # checked on 2019-12-11 that these are consolidated ten-thousand blocks
-    # next check due 2020-12-01 (annually)
+    # checked on 2020-12-04 that these are consolidated ten-thousand blocks
+    # next check due 2021-12-01 (annually)
     # https://localcallingguide.com/xmlprefix.php?npa=630&blocks=1
-    # https://localcallingguide.com/xmlprefix.php?npa=242&blocks=1
     is($CLASS->new('+1 630 847 0000')->operator(), 'YMAX COMMUNICATIONS CORP. - IL', 'USA, thousands blocks all for same operator, so consolidated into one to save space in database');
-    # checked on 2019-12-11
-    # next check due 2020-12-01 (annually)
+    # checked on 2020-12-04
+    # next check due 2021-12-01 (annually)
+    # https://localcallingguide.com/xmlprefix.php?npa=242&blocks=1
     is($CLASS->new('+1 242 367 0000')->operator(), 'BAHAMAS TELECOMMUNICATIONS CORP.', 'Bahamas, thousands blocks all for same operator, so consolidated into one to save space in database');
 
     foreach my $number(
@@ -194,16 +194,16 @@ skip_if_libphonenumber("Stubs don't support operator", 1, sub {
         [ 'Bahamas', '+1 242 331 7000', undef ],
         [ 'Bahamas', '+1 242 331 8000', undef ],
         [ 'Bahamas', '+1 242 331 9000', undef ],
-        [ 'USA',     '+1 512 373 0000', 'SPRINT SPECTRUM L.P.' ],
+        [ 'USA',     '+1 512 373 0000', 'SPRINT SPECTRUM, L.P.' ],
         [ 'USA',     '+1 512 373 1000', undef ],
-        [ 'USA',     '+1 512 373 2000', 'SPRINT SPECTRUM L.P.', ],
+        [ 'USA',     '+1 512 373 2000', 'SPRINT SPECTRUM, L.P.', ],
         [ 'USA',     '+1 512 373 3000', 'TIME WARNER CBLE INFO SVC (TX) DBA TIME WARNER CBL', ],
         [ 'USA',     '+1 512 373 4000', undef ],
-        [ 'USA',     '+1 512 373 5000', 'SPRINT SPECTRUM L.P.' ],
-        [ 'USA',     '+1 512 373 6000', 'SPRINT SPECTRUM L.P.' ],
+        [ 'USA',     '+1 512 373 5000', 'SPRINT SPECTRUM, L.P.' ],
+        [ 'USA',     '+1 512 373 6000', 'SPRINT SPECTRUM, L.P.' ],
         [ 'USA',     '+1 512 373 7000', undef ],
         [ 'USA',     '+1 512 373 8000', 'TIME WARNER CBLE INFO SVC (TX) DBA TIME WARNER CBL' ],
-        [ 'USA',     '+1 512 373 9000', 'SPRINT SPECTRUM L.P.' ]
+        [ 'USA',     '+1 512 373 9000', 'SPRINT SPECTRUM, L.P.' ]
     ) {
         is(
             $CLASS->new($number->[1])->operator(),
